Ortho-rectification methodology (sarpy.processing.ortho_rectify)
================================================================

.. automodule:: sarpy.processing.ortho_rectify
    :members:
    :show-inheritance:
    :inherited-members:
